@@ -47,7 +47,8 @@ enum Optcode {
         S_OPT_PRETTY_SYMBOLS, S_OPT_EOL_DELIM_CR, S_OPT_START_NESTED,
         S_OPT_PRINT_STYLE, S_OPT_NO_TRAILING_NL, S_OPT_PLUGIN, S_OPT_ABS_CFG_PATH,
         S_OPT_PLUGIN_READFILE, S_OPT_PLUGIN_PARAMETER, S_OPT_LIST_SCRIPTS, S_OPT_CANVAS,
-        S_OPT_KEEP_INJECTIONS, S_OPT_FORCE_STDOUT, S_OPT_LATEX_BEAMER, S_OPT_NO_VERSION_INFO
+        S_OPT_KEEP_INJECTIONS, S_OPT_FORCE_STDOUT, S_OPT_LATEX_BEAMER, S_OPT_NO_VERSION_INFO,
+        S_OPT_REFORMAT_OPT, S_OPT_RANGE_OPT
     };
 
 const Arg_parser::Option options[] = {
@@ -131,6 +132,9 @@ const Arg_parser::Option options[] = {
         { S_OPT_ABS_CFG_PATH,     OPT_ABS_CFG_PATH,    Arg_parser::yes},
         { S_OPT_LIST_SCRIPTS,     OPT_LIST_SCRIPTS,    Arg_parser::yes},
         { S_OPT_CANVAS,           OPT_CANVAS,          Arg_parser::maybe },
+        { S_OPT_REFORMAT_OPT,     OPT_REFORMAT_OPT,    Arg_parser::yes },
+        { S_OPT_RANGE_OPT,        OPT_RANGE_OPT,    Arg_parser::yes },
+
 
         { 0, 0, Arg_parser::no }
     };
@@ -142,6 +146,8 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
     lineNrWidth ( 5 ),
     lineLength ( 80 ),
     lineNrStart ( 1 ),
+    lineRangeStart( 0 ),
+    lineRangeEnd( 0 ),
     canvasPaddingWidth(0),
     wrappingStyle ( highlight::WRAP_DISABLED ),
     outputType ( highlight::HTML ),
@@ -461,7 +467,9 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
         case S_OPT_PLUGIN:
             userPlugins.push_back(arg);
             break;
-
+        case S_OPT_REFORMAT_OPT:
+            astyleOptions.push_back(arg);
+            break;
         case S_OPT_PLUGIN_PARAMETER:
         case S_OPT_PLUGIN_READFILE:
             pluginParameter=arg;
@@ -510,6 +518,19 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
             } else if (arg.find(".theme")!=string::npos) absThemePath=arg;
             else cerr << "highlight: unknown config file type" << endl;
             break;
+        
+        case S_OPT_RANGE_OPT: {
+            size_t delimPos=arg.find("-");
+            if (delimPos!=string::npos) {
+                StringTools::str2num<int> ( lineRangeStart, arg.substr(0, delimPos), std::dec );
+                StringTools::str2num<int> ( lineRangeEnd, arg.substr(delimPos+1), std::dec );
+                lineRangeEnd = lineRangeEnd - lineRangeStart + 1;
+                if (lineRangeEnd<=0 || lineRangeStart <=0) {
+                    lineRangeStart = lineRangeEnd = 0;
+                }
+            }
+            break;
+        }
         case S_OPT_LIST_SCRIPTS:
             opt_show_themes=(arg=="themes");
             opt_show_plugins=(arg=="plugins");
@@ -734,6 +755,10 @@ const vector<string> &CmdLineOptions::getPluginPaths() const
 {
     return userPlugins;
 }
+const vector<string> &CmdLineOptions::getAStyleOptions() const
+{
+    return astyleOptions;
+}
 bool CmdLineOptions::printOnlyStyle() const
 {
     return opt_print_style;
@@ -919,3 +944,13 @@ int CmdLineOptions::getCanvasPadding()
 {
     return canvasPaddingWidth;
 }
+
+int CmdLineOptions::getLineRangeStart()
+{
+    return lineRangeStart;
+}
+
+int CmdLineOptions::getLineRangeEnd()
+{
+    return lineRangeEnd;
+}
