@@ -2,7 +2,7 @@
                           help.cpp  -  description
                              -------------------
     begin                : Die Apr 23 2002
-    copyright            : (C) 2002-2017 by Andre Simon
+    copyright            : (C) 2002-2018 by Andre Simon
     email                : andre.simon1@gmx.de
  ***************************************************************************/
 
@@ -78,12 +78,17 @@ void printHelp()
 
     cout<<" -f, --fragment                 omit document header and footer\n";
     cout<<" -F, --reformat=<style>         reformats and indents output in given style\n";
-    cout<<"                                  <style> = [allman, banner, gnu,\n";
-    cout<<"                                  horstmann, java, kr, linux, mozilla, otbs, vtk,\n";
-    cout<<"                                  stroustrup, whitesmith, google, pico, lisp]\n";
+    cout<<"                                  <style> = [allman, gnu, google, horstmann,\n";
+    cout<<"                                  java, kr, linux, lisp, mozilla, otbs, pico,\n";
+    cout<<"                                  vtk, ratliff, stroustrup, webkit, whitesmith, user]\n";
+    cout<<"                                  The user style does not apply a predefined scheme.\n";
+    cout<<"                                  Use --reformat-option to define the reformatting.\n";
+    cout<<"     --reformat-option=<opt>    apply an astyle cmd line option (assumes -F)\n";
     cout<<" -I, --include-style            include style definition in output file\n";
     cout<<" -J, --line-length=<num>        line length before wrapping (see -V, -W)\n";
     cout<<" -j, --line-number-length=<num> line number width incl. left padding (default: 5)\n";
+    cout<<"     --line-range=<start-end>   output only lines from number <start> to <end>\n";
+
     cout<<" -k, --font=<font>              set font (specific to output format)\n";
     cout<<" -K, --font-size=<num?>         set font size (specific to output format)\n";
     cout<<" -l, --line-numbers             print line numbers in output file\n";
@@ -141,6 +146,11 @@ void printHelp()
     cout<<"     --width                    set image width (see --height)\n";
     cout<<"\n";
     cout<<"\n";
+    cout<<"Terminal escape output options (xterm256 or truecolor):\n";
+    cout<<"\n";
+    cout<<"     --canvas[=width]           set background colour padding (default: 80)\n";
+    cout<<"\n";
+    cout<<"\n";
     cout<<"GNU source-highlight compatibility options:\n";
     cout<<"\n";
     cout<<"     --doc                      create stand alone document\n";
@@ -163,7 +173,8 @@ void printHelp()
     cout<<"if neither -c nor -I is given.\n";
     cout<<"Reformatting code (-F) will only work with C, C++, C# and Java input files.\n";
     cout<<"Wrapping lines with -V or -W will cause faulty highlighting of long single\n";
-    cout<<"line comments and directives. Use with caution.\n\n";
+    cout<<"line comments and directives. Using line-range might interfere with multi\n";
+    cout<<"line syntax elements. Use with caution.\n\n";
     cout<<"Run highlight --list-scripts=langs to see all supported syntax types.\n\n";
     cout<<"Refer to README files how to apply plug-ins to customize the output.\n\n";
     cout<<"Updates and information: http://www.andre-simon.de/\n";
