@@ -2,7 +2,7 @@
                    xterm256generator.cpp  -  description
                              -------------------
     begin                : Oct 13 2006
-    copyright            : (C) 2006 by Andre Simon
+    copyright            : (C) 2006-2018 by Andre Simon
     email                : andre.simon1@gmx.de
  ***************************************************************************/
 
@@ -43,6 +43,7 @@ Xterm256Generator::Xterm256Generator() :
 {
     newLineTag = "\n";
     spacer = " ";
+    maskWs=true; // needed if canvasPadding > 0; requires tab replacement
 }
 
 Xterm256Generator::~Xterm256Generator() {}
@@ -59,7 +60,7 @@ void Xterm256Generator::printBody()
 
 string Xterm256Generator::getFooter()
 {
-    return string();
+    return string("\033[m");
 }
 
 string Xterm256Generator::maskCharacter ( unsigned char c )
@@ -69,6 +70,25 @@ string Xterm256Generator::maskCharacter ( unsigned char c )
 
 void Xterm256Generator::initOutputTags ( )
 {
+    if (canvasPadding > 0 ) {
+
+        ostringstream bgs;
+        Colour bg=docStyle.getBgColour();
+        unsigned char  bg_rgb[3];
+        bg_rgb[0] = ( unsigned char ) strtoll ( bg.getRed ( HTML ).c_str(), NULL, 16 );
+        bg_rgb[1] = ( unsigned char ) strtoll ( bg.getGreen ( HTML ).c_str(), NULL, 16 );
+        bg_rgb[2] = ( unsigned char ) strtoll ( bg.getBlue ( HTML ).c_str(), NULL, 16 );
+        
+        if (use16mColours) {
+            //use 24bit true colour ("888" colours (aka 16 milion))
+            bgs << "\033[48;2;"<< ( int ) bg_rgb[0] << ";" << ( int ) bg_rgb[1] << ";" << ( int ) bg_rgb[2] << "m";
+        } else {
+            int bgApprox=( int ) rgb2xterm ( bg_rgb );
+            if (!bgApprox) bgApprox=16; // workaround transparent 0 value
+            bgs << "\033[48;5;"<< bgApprox << "m";
+        }
+        canvasColSeq = bgs.str();
+    }    
     openTags.push_back ( getOpenTag ( docStyle.getDefaultStyle() ) );
     openTags.push_back ( getOpenTag ( docStyle.getStringStyle() ) );
     openTags.push_back ( getOpenTag ( docStyle.getNumberStyle() ) );
@@ -83,12 +103,11 @@ void Xterm256Generator::initOutputTags ( )
 
     for (unsigned int i=0; i<NUMBER_BUILTIN_STATES; i++ ) {
         closeTags.push_back ( "\033[m" );
-    }
+    }    
 }
 
 string  Xterm256Generator::getOpenTag ( const ElementStyle &col )
 {
-
     Colour c= col.getColour();
     unsigned char  rgb[3];
     rgb[0] = ( unsigned char ) strtoll ( c.getRed ( HTML ).c_str(), NULL, 16 );
@@ -96,13 +115,15 @@ string  Xterm256Generator::getOpenTag ( const ElementStyle &col )
     rgb[2] = ( unsigned char ) strtoll ( c.getBlue ( HTML ).c_str(), NULL, 16 );
 
     ostringstream s;
+    
+    s << canvasColSeq;
+    
     s  << "\033[";
 
     if ( col.isBold() ) s << "1;";
     if ( col.isItalic() ) s << "3;";
     if ( col.isUnderline() ) s << "4;";
 
-
     if (use16mColours) {
         //use 24bit true colour ("888" colours (aka 16 milion))
         s << "38;2;"<< ( int ) rgb[0] << ";" << ( int ) rgb[1] << ";" << ( int ) rgb[2] << "m";
@@ -123,6 +144,35 @@ string Xterm256Generator::getKeywordCloseTag ( unsigned int styleID )
     return "\033[m";
 }
 
+string Xterm256Generator::getNewLine()
+{
+    string nlStr;
+    
+    if (canvasPadding>0) {
+        unsigned int lastLineLength=getLastLineLength();
+        
+        //adapt to long lines; avoid lag with very long lines
+        if (lastLineLength<512 && lastLineLength > canvasPadding && lastLineLength)
+            canvasPadding = lastLineLength;
+        
+        nlStr += canvasColSeq;
+        if (canvasPadding > lastLineLength)
+            nlStr += string(canvasPadding - lastLineLength, ' ');
+        nlStr += "\033[m";    
+    } 
+    nlStr += (printNewLines) ? newLineTag : "";
+    return nlStr;
+}
+
+ void Xterm256Generator::setESCTrueColor(bool b) { 
+    use16mColours = b; 
+    if (b) setOutputType(ESC_TRUECOLOR); 
+} 
+    
+void Xterm256Generator::setESCCanvasPadding(unsigned int p) { 
+    if (p<512) canvasPadding = p; 
+}
+
 /* the following functions are based on Wolfgang Frischs xterm256 converter utility:
    http://frexx.de/xterm-256-notes/
 */
