@@ -1,5 +1,5 @@
 // astyle.h
-// Copyright (c) 2017 by Jim Pattee <jimp03@email.com>.
+// Copyright (c) 2018 by Jim Pattee <jimp03@email.com>.
 // This code is licensed under the MIT License.
 // License.md describes the conditions under which this software may be distributed.
 
@@ -78,13 +78,14 @@ enum FormatStyle
 	STYLE_STROUSTRUP,
 	STYLE_WHITESMITH,
 	STYLE_VTK,
-	STYLE_BANNER,
+	STYLE_RATLIFF,
 	STYLE_GNU,
 	STYLE_LINUX,
 	STYLE_HORSTMANN,
 	STYLE_1TBS,
 	STYLE_GOOGLE,
 	STYLE_MOZILLA,
+	STYLE_WEBKIT,
 	STYLE_PICO,
 	STYLE_LISP
 };
@@ -98,7 +99,7 @@ enum BraceMode
 	RUN_IN_MODE		// broken braces
 };
 
-// maximun value for int is 16,384 (total value of 32,767)
+// maximum value for int is 16,384 (total value of 32,767)
 enum BraceType
 {
 	NULL_TYPE        = 0,
@@ -155,9 +156,10 @@ enum ReferenceAlign
 
 enum FileEncoding
 {
-	ENCODING_8BIT,
+	ENCODING_8BIT,  // includes UTF-8 without BOM
+	UTF_8BOM,       // UTF-8 with BOM
 	UTF_16BE,
-	UTF_16LE,     // Windows default
+	UTF_16LE,       // Windows default
 	UTF_32BE,
 	UTF_32LE
 };
@@ -184,11 +186,12 @@ enum LineEndFormat
 class ASSourceIterator
 {
 public:
-	ASSourceIterator() {}
-	virtual ~ASSourceIterator() {}
+	ASSourceIterator() = default;
+	virtual ~ASSourceIterator() = default;
+	virtual streamoff getPeekStart() const = 0;
 	virtual int getStreamLength() const = 0;
 	virtual bool hasMoreLines() const = 0;
-	virtual string nextLine(bool emptyLineWasDeleted = false) = 0;
+	virtual string nextLine(bool emptyLineWasDeleted) = 0;
 	virtual string peekNextLine() = 0;
 	virtual void peekReset() = 0;
 	virtual streamoff tellg() = 0;
@@ -294,10 +297,10 @@ class ASBase : protected ASResource
 {
 private:
 	// all variables should be set by the "init" function
-	int baseFileType;      // a value from enum FileType
+	int baseFileType = C_TYPE;      // a value from enum FileType
 
 protected:
-	ASBase() : baseFileType(C_TYPE) { }
+	ASBase() = default;
 
 protected:  // inline functions
 	void init(int fileTypeArg) { baseFileType = fileTypeArg; }
@@ -331,7 +334,12 @@ class ASBeautifier : protected ASBase
 public:
 	ASBeautifier();
 	virtual ~ASBeautifier();
+	ASBeautifier(const ASBeautifier& other);
+	ASBeautifier& operator=(ASBeautifier const&) = delete;
+	ASBeautifier(ASBeautifier&&)                 = delete;
+	ASBeautifier& operator=(ASBeautifier&&)      = delete;
 	virtual void init(ASSourceIterator* iter);
+
 	virtual string beautify(const string& originalLine);
 	void setCaseIndent(bool state);
 	void setClassIndent(bool state);
@@ -404,9 +412,6 @@ protected:
 	bool isInIndentablePreproc;
 
 private:  // functions
-	ASBeautifier(const ASBeautifier& other);     // inline functions
-	ASBeautifier& operator=(ASBeautifier&);      // not to be implemented
-
 	void adjustObjCMethodDefinitionIndentation(const string& line_);
 	void adjustObjCMethodCallIndentation(const string& line_);
 	void adjustParsedLineIndentation(size_t iPrelim, bool isInExtraHeaderIndent);
@@ -426,6 +431,7 @@ private:  // functions
 	int  adjustIndentCountForBreakElseIfComments() const;
 	int  computeObjCColonAlignment(const string& line, int colonAlignPosition) const;
 	int  convertTabToSpaces(int i, int tabIncrementIn) const;
+	int  findObjCColonAlignment(const string& line) const;
 	int  getContinuationIndentAssign(const string& line, size_t currPos) const;
 	int  getContinuationIndentComma(const string& line, size_t currPos) const;
 	int  getObjCFollowingKeyword(const string& line, int bracePos) const;
@@ -433,6 +439,7 @@ private:  // functions
 	bool isLineEndComment(const string& line, int startPos) const;
 	bool isPreprocessorConditionalCplusplus(const string& line) const;
 	bool isInPreprocessorUnterminatedComment(const string& line);
+	bool isTopLevel() const;
 	bool statementEndsWithComma(const string& line, int index) const;
 	const string& getIndentedLineReturn(const string& newLine, const string& originalLine) const;
 	string getIndentedSpaceEquivalent(const string& line_) const;
@@ -458,7 +465,7 @@ private:  // variables
 	vector<int>* activeBeautifierStackLengthStack;
 	vector<const string*>* headerStack;
 	vector<vector<const string*>* >* tempStacks;
-	vector<int>* squareBracketDepthStack;
+	vector<int>* parenDepthStack;
 	vector<bool>* blockStatementStack;
 	vector<bool>* parenStatementStack;
 	vector<bool>* braceBlockStateStack;
@@ -506,6 +513,7 @@ private:  // variables
 	bool isInEnum;
 	bool isInEnumTypeID;
 	bool isInLet;
+	bool isInTrailingReturnType;
 	bool modifierIndent;
 	bool switchIndent;
 	bool caseIndent;
@@ -575,8 +583,7 @@ private:  // variables
 class ASEnhancer : protected ASBase
 {
 public:  // functions
-	ASEnhancer();
-	virtual ~ASEnhancer();
+	ASEnhancer() = default;
 	void init(int, int, int, bool, bool, bool, bool, bool, bool, bool,
 	          vector<const pair<const string, const string>* >*);
 	void enhance(string& line, bool isInNamespace, bool isInPreprocessor, bool isInSQL);
@@ -651,10 +658,15 @@ class ASFormatter : public ASBeautifier
 {
 public:	// functions
 	ASFormatter();
-	virtual ~ASFormatter();
-	virtual void init(ASSourceIterator* si);
-	virtual bool hasMoreLines() const;
-	virtual string nextLine();
+	~ASFormatter() override;
+	ASFormatter(const ASFormatter&)            = delete;
+	ASFormatter& operator=(ASFormatter const&) = delete;
+	ASFormatter(ASFormatter&&)                 = delete;
+	ASFormatter& operator=(ASFormatter&&)      = delete;
+	void init(ASSourceIterator* si) override;
+
+	bool hasMoreLines() const;
+	string nextLine();
 	LineEndFormat getLineEndFormat() const;
 	bool getIsLineReady() const;
 	void setFormattingStyle(FormatStyle style);
@@ -684,6 +696,10 @@ public:	// functions
 	void setCloseTemplatesMode(bool state);
 	void setCommaPaddingMode(bool state);
 	void setDeleteEmptyLinesMode(bool state);
+	void setBreakReturnType(bool state);
+	void setBreakReturnTypeDecl(bool state);
+	void setAttachReturnType(bool state);
+	void setAttachReturnTypeDecl(bool state);
 	void setIndentCol1CommentsMode(bool state);
 	void setLineEndFormat(LineEndFormat fmt);
 	void setMaxCodeLength(int max);
@@ -703,7 +719,7 @@ public:	// functions
 	size_t getChecksumOut() const;
 	int  getChecksumDiff() const;
 	int  getFormatterFileType() const;
-	// retained for compatability with release 2.06
+	// retained for compatibility with release 2.06
 	// "Brackets" have been changed to "Braces" in 3.0
 	// they are referenced only by the old "bracket" options
 	void setAddBracketsMode(bool state);
@@ -713,8 +729,6 @@ public:	// functions
 
 
 private:  // functions
-	ASFormatter(const ASFormatter& copy);       // not to be implemented
-	ASFormatter& operator=(ASFormatter&);       // not to be implemented
 	template<typename T> void deleteContainer(T& container);
 	template<typename T> void initContainer(T& container, T value);
 	char peekNextChar() const;
@@ -743,10 +757,12 @@ private:  // functions
 	bool isMultiStatementLine() const;
 	bool isNextWordSharpNonParenHeader(int startChar) const;
 	bool isNonInStatementArrayBrace() const;
+	bool isNumericVariable(const string& word) const;
 	bool isOkToSplitFormattedLine();
 	bool isPointerOrReference() const;
 	bool isPointerOrReferenceCentered() const;
 	bool isPointerOrReferenceVariable(const string& word) const;
+	bool isPointerToPointer(const string& line, int currPos) const;
 	bool isSharpStyleWithParen(const string* header) const;
 	bool isStructAccessModified(const string& firstLine, size_t index) const;
 	bool isIndentablePreprocessorBlock(const string& firstLine, size_t index);
@@ -780,6 +796,7 @@ private:  // functions
 	void clearFormattedLineSplitPoints();
 	void convertTabToSpaces();
 	void deleteContainer(vector<BraceType>*& container);
+	void findReturnTypeSplitPoint(const string& firstLine);
 	void formatArrayRunIn();
 	void formatRunIn();
 	void formatArrayBraces(BraceType braceType, bool isOpeningArrayBrace);
@@ -822,7 +839,7 @@ private:  // functions
 	string getPreviousWord(const string& line, int currPos) const;
 	string peekNextText(const string& firstLine,
 	                    bool endOnEmptyLine = false,
-	                    shared_ptr<ASPeekStream> streamArg = nullptr) const;
+	                    const shared_ptr<ASPeekStream>& streamArg = nullptr) const;
 
 private:  // variables
 	int formatterFileType;
@@ -870,6 +887,10 @@ private:  // variables
 	size_t formattedLineCommentNum;     // comment location on formattedLine
 	size_t leadingSpaces;
 	size_t maxCodeLength;
+	size_t methodAttachCharNum;
+	size_t methodAttachLineNum;
+	size_t methodBreakCharNum;
+	size_t methodBreakLineNum;
 
 	// possible split points
 	size_t maxSemi;			// probably a 'for' statement
@@ -971,10 +992,12 @@ private:  // variables
 	bool isInObjCMethodDefinition;
 	bool isInObjCInterface;
 	bool isInObjCReturnType;
+	bool isInObjCParam;
 	bool isInObjCSelector;
 	bool breakCurrentOneLineBlock;
 	bool shouldRemoveNextClosingBrace;
 	bool isInBraceRunIn;
+	bool returnTypeChecked;
 	bool currentLineBeginsWithBrace;
 	bool attachClosingBraceMode;
 	bool shouldBreakOneLineBlocks;
@@ -995,6 +1018,10 @@ private:  // variables
 	bool shouldPadParamType;
 	bool shouldUnPadParamType;
 	bool shouldDeleteEmptyLines;
+	bool shouldBreakReturnType;
+	bool shouldBreakReturnTypeDecl;
+	bool shouldAttachReturnType;
+	bool shouldAttachReturnTypeDecl;
 	bool needHeaderOpeningBrace;
 	bool shouldBreakLineAtNextChar;
 	bool shouldKeepLineUnbroken;
